<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.pkexec.logViewerTruncate!message" line="0"/>
			<source>Authentication is required to clear the log</source>
			<translation>Wymagane jest uwierzytelnienie do wyczyszczenia logów</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.logViewerTruncate!description" line="0"/>
			<source>authentication</source>
			<translation>uwierzytelnienie</translation>
		</message>
	</context>
</TS>